
![Logo](https://github.com/neetishsingh/customItems/blob/main/LogoMakr-4DZdLc.png?raw=true)



[![MIT License](https://img.shields.io/badge/License-MIT-green.svg)](https://choosealicense.com/licenses/mit/)


Sharevia is a python tool through which you can share any amount of data to multiple devices at once without any need of installing any extra software or mobile app.


## Authors

- [@neetishsingh](https://github.com/neetishsingh/sharevia)


## How to run

Best part of Sharevia is you just need two lines of code to initiate it.

1.To install sharevia python package.
```bash
  pip install sharevia
```

2.Now start the app
```bash
  python -m sharevia
```
Note: The only requirement to take benifit of this sharing framework in that you need to have python installed in any of the device atleast.



    
## Demo

Once the server will be on you will see similar portal on `http://127.0.0.1/a/` 
![alt text](https://raw.githubusercontent.com/neetishsingh/customItems/3a68c2ad873c65450425b432bf2aba54e71b29b1/FullUI1.PNG)

To Access files over any other device connected over same network we need to scan this qr from the device or in browser open `http://ip_adr_of_parent_device:8000/a/`
![alt text](https://raw.githubusercontent.com/neetishsingh/customItems/main/auth.jpeg)

Once you will enter the auth code you will get the files easily over responsive website
![alt text](https://github.com/neetishsingh/customItems/blob/main/WhatsApp%20Image%202023-01-16%20at%2013.15.45.jpeg?raw=true)

There is a lot more coming whose screenshot will be added soon 


## Features to be added in next version

- File/Folder Share permission 
- Live previews
- Movie/Video Streaming
- Music Playlist & Streaming
- IP Logging
- UI Improvement
- Admin Level Customizations


## Contributing

Contributions are always welcome!

Lets connect and discuss your ideas and scope of improvement

Please adhere to this project's `code of conduct`.


## Support

For support, email neetishsingh97@gmail.com or call me at +91-9643046366.

